@@ -11,13 +11,7 @@ import sys
 
 __email__="3416445406@qq.com"
 __author__="七分诚意 qq:3076711200 邮箱:%s"%__email__
-__version__="1.0"
-
-def crash():
-    #引发无穷递归,使程序崩溃。
-    def _crash():_crash()
-    sys.setrecursionlimit(10000)
-    _crash()
+__version__="1.1"
 
 try:
     try: import catch_turtle.catch_turtle as catch_turtle
@@ -25,7 +19,6 @@ try:
 except ImportError as err:
     message="错误:找不到游戏核心模块: %s"%err.name
     print(message,file=sys.stderr)
-    crash()
 
 #相当于from xxmodule import *
 scope=globals()
@@ -36,5 +29,4 @@ for attr in dir(catch_turtle):
         if not getattr(obj,"__module__",None)=="turtle":
             scope[attr]=obj
 
-del crash
 if __name__=='__main__':start()
